import { CloudEvent, CloudFunction } from '../../core';
import * as options from '../../options';
/**
 * The CloudEvent data emitted by Firebase Alerts.
 */
export interface FirebaseAlertData<T = any> {
    /** Time that the event has created. */
    createTime: string;
    /** Time that the event has ended. Optional, only present for ongoing alerts. */
    endTime: string;
    /** Payload of the event, which includes the details of the specific alert. */
    payload: T;
}
/**
 * A custom CloudEvent for Firebase Alerts (with custom extension attributes).
 */
export interface AlertEvent<T> extends CloudEvent<FirebaseAlertData<T>> {
    /** The type of the alerts that got triggered. */
    alertType: string;
    /**
     * The Firebase App ID that’s associated with the alert. This is optional,
     * and only present when the alert is targeting at a specific Firebase App.
     */
    appId?: string;
    /** Data for an AlertEvent is a FirebaseAlertData with a given payload. */
    data: FirebaseAlertData<T>;
}
/** The underlying alert type of the Firebase Alerts provider. */
export declare type AlertType = 'crashlytics.newFatalIssue' | 'crashlytics.newNonfatalIssue' | 'crashlytics.regression' | 'crashlytics.stabilityDigest' | 'crashlytics.velocity' | 'crashlytics.newAnrIssue' | 'billing.planUpdate' | 'billing.automatedPlanUpdate' | 'appDistribution.newTesterIosDevice' | string;
/**
 * Configuration for Firebase Alert functions.
 */
export interface FirebaseAlertOptions extends options.EventHandlerOptions {
    alertType: AlertType;
    appId?: string;
}
/**
 * Declares a function that can handle Firebase Alerts from CloudEvents.
 * @param alertTypeOrOpts the alert type or Firebase Alert function configuration.
 * @param handler a function that can handle the Firebase Alert inside a CloudEvent.
 */
export declare function onAlertPublished<T extends {
    ['@type']: string;
} = any>(alertTypeOrOpts: AlertType | FirebaseAlertOptions, handler: (event: AlertEvent<T>) => any | Promise<any>): CloudFunction<AlertEvent<T>>;
