import { FirebaseAlertData } from '.';
import { CloudEvent, CloudFunction } from '../../core';
import * as options from '../../options';
/** Generic crashlytics issue interface */
interface Issue {
    id: string;
    title: string;
    subtitle: string;
    appVersion: string;
}
/**
 * The internal payload object for a new fatal issue.
 * Payload is wrapped inside a FirebaseAlertData object.
 */
export interface NewFatalIssuePayload {
    ['@type']: 'type.googleapis.com/google.events.firebase.firebasealerts.v1.CrashlyticsNewFatalIssuePayload';
    /** Basic information of the Crashlytics issue */
    issue: Issue;
}
/**
 * The internal payload object for a new non-fatal issue.
 * Payload is wrapped inside a FirebaseAlertData object.
 */
export interface NewNonfatalIssuePayload {
    ['@type']: 'type.googleapis.com/google.events.firebase.firebasealerts.v1.CrashlyticsNewNonfatalIssuePayload';
    /** Basic information of the Crashlytics issue */
    issue: Issue;
}
/**
 * The internal payload object for a regression alert.
 * Payload is wrapped inside a FirebaseAlertData object.
 */
export interface RegressionAlertPayload {
    ['@type']: 'type.googleapis.com/google.events.firebase.firebasealerts.v1.CrashlyticsRegressionAlertPayload';
    /** The type of the Crashlytics issue, e.g. new fatal, new nonfatal, ANR */
    type: string;
    /** Basic information of the Crashlytics issue */
    issue: Issue;
    /**
     * The time that the Crashlytics issues was most recently resolved before it
     * began to reoccur.
     */
    resolveTime: string;
}
/** Generic crashlytics trending issue interface */
interface TrendingIssueDetails {
    /** The type of the Crashlytics issue, e.g. new fatal, new nonfatal, ANR */
    type: string;
    /** Basic information of the Crashlytics issue */
    issue: Issue;
    /** The number of crashes that occurred with the issue */
    eventCount: number;
    /** The number of distinct users that were affected by the issue */
    userCount: number;
}
/**
 * The internal payload object for a stability digest.
 * Payload is wrapped inside a FirebaseAlertData object.
 */
export interface StabilityDigestPayload {
    ['@type']: 'type.googleapis.com/google.events.firebase.firebasealerts.v1.CrashlyticsStabilityDigestPayload';
    /**
     * The date that the digest gets created. Issues in the digest should have the
     * same date as the digest date
     */
    digestDate: string;
    /** A stability digest containing several trending Crashlytics issues */
    trendingIssues: TrendingIssueDetails[];
}
/**
 * The internal payload object for a velocity alert.
 * Payload is wrapped inside a FirebaseAlertData object.
 */
export interface VelocityAlertPayload {
    ['@type']: 'type.googleapis.com/google.events.firebase.firebasealerts.v1.CrashlyticsVelocityAlertPayload';
    /** Basic information of the Crashlytics issue */
    issue: Issue;
    /** The time that the Crashlytics issue gets created */
    createTime: string;
    /**
     * The number of user sessions for the given app version that had this
     * specific crash issue in the time period used to trigger the velocity alert.
     */
    crashCount: number;
    /**
     * The percentage of user sessions for the given app version that had this
     * specific crash issue in the time period used to trigger the velocity alert.
     */
    crashPercentage: number;
    /**
     * The first app version where this issue was seen, and not necessarily the
     * version that has triggered the alert.
     */
    firstVersion: string;
}
/**
 * The internal payload object for a new Application Not Responding issue.
 * Payload is wrapped inside a FirebaseAlertData object.
 */
export interface NewAnrIssuePayload {
    ['@type']: 'type.googleapis.com/google.events.firebase.firebasealerts.v1.CrashlyticsNewAnrIssuePayload';
    /** Basic information of the Crashlytics issue */
    issue: Issue;
}
/**
 * A custom CloudEvent for Firebase Alerts (with custom extension attributes).
 */
export interface CrashlyticsEvent<T> extends CloudEvent<FirebaseAlertData<T>> {
    /** The type of the alerts that got triggered. */
    alertType: string;
    /** The Firebase App ID that’s associated with the alert. */
    appId: string;
}
/**
 * Configuration for crashlytics functions.
 */
export interface CrashlyticsOptions extends options.EventHandlerOptions {
    appId?: string;
}
/**
 * Declares a function that can handle a new fatal issue published to crashlytics.
 */
export declare function onNewFatalIssuePublished(handler: (event: CrashlyticsEvent<NewFatalIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewFatalIssuePayload>>;
export declare function onNewFatalIssuePublished(appId: string, handler: (event: CrashlyticsEvent<NewFatalIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewFatalIssuePayload>>;
export declare function onNewFatalIssuePublished(opts: CrashlyticsOptions, handler: (event: CrashlyticsEvent<NewFatalIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewFatalIssuePayload>>;
/**
 * Declares a function that can handle aa new non-fatal issue published to crashlytics.
 */
export declare function onNewNonfatalIssuePublished(handler: (event: CrashlyticsEvent<NewNonfatalIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewNonfatalIssuePayload>>;
export declare function onNewNonfatalIssuePublished(appId: string, handler: (event: CrashlyticsEvent<NewNonfatalIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewNonfatalIssuePayload>>;
export declare function onNewNonfatalIssuePublished(opts: CrashlyticsOptions, handler: (event: CrashlyticsEvent<NewNonfatalIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewNonfatalIssuePayload>>;
/**
 * Declares a function that can handle a regression alert published to crashlytics.
 */
export declare function onRegressionAlertPublished(handler: (event: CrashlyticsEvent<RegressionAlertPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<RegressionAlertPayload>>;
export declare function onRegressionAlertPublished(appId: string, handler: (event: CrashlyticsEvent<RegressionAlertPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<RegressionAlertPayload>>;
export declare function onRegressionAlertPublished(opts: CrashlyticsOptions, handler: (event: CrashlyticsEvent<RegressionAlertPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<RegressionAlertPayload>>;
/**
 * Declares a function that can handle a stability digest published to crashlytics.
 */
export declare function onStabilityDigestPublished(handler: (event: CrashlyticsEvent<StabilityDigestPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<StabilityDigestPayload>>;
export declare function onStabilityDigestPublished(appId: string, handler: (event: CrashlyticsEvent<StabilityDigestPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<StabilityDigestPayload>>;
export declare function onStabilityDigestPublished(opts: CrashlyticsOptions, handler: (event: CrashlyticsEvent<StabilityDigestPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<StabilityDigestPayload>>;
/**
 * Declares a function that can handle a velocity alert published to crashlytics.
 */
export declare function onVelocityAlertPublished(handler: (event: CrashlyticsEvent<VelocityAlertPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<VelocityAlertPayload>>;
export declare function onVelocityAlertPublished(appId: string, handler: (event: CrashlyticsEvent<VelocityAlertPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<VelocityAlertPayload>>;
export declare function onVelocityAlertPublished(opts: CrashlyticsOptions, handler: (event: CrashlyticsEvent<VelocityAlertPayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<VelocityAlertPayload>>;
/**
 * Declares a function that can handle a new Application Not Responding issue published to crashlytics.
 */
export declare function onNewAnrIssuePublished(handler: (event: CrashlyticsEvent<NewAnrIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewAnrIssuePayload>>;
export declare function onNewAnrIssuePublished(appId: string, handler: (event: CrashlyticsEvent<NewAnrIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewAnrIssuePayload>>;
export declare function onNewAnrIssuePublished(opts: CrashlyticsOptions, handler: (event: CrashlyticsEvent<NewAnrIssuePayload>) => any | Promise<any>): CloudFunction<CrashlyticsEvent<NewAnrIssuePayload>>;
export {};
